@@ -1,6 +1,6 @@
 package Runops::Recorder;
 
-use 5.010000;
+use 5.010;
 
 use strict;
 use warnings;
@@ -9,14 +9,16 @@ use Carp;
 use File::Path qw(make_path);
 use POSIX qw(strftime);
 
-our $VERSION = '0.07';
+use constant DEFAULT_BUFFER_SIZE => 64 * 1024;
+
+our $VERSION = '0.08';
 
 require XSLoader;
 XSLoader::load('Runops::Recorder', $VERSION);
 
 sub import {
     my ($pkg, @opts) = @_;
-
+    
     my $target_dir;
     $target_dir = $opts[0] if defined $opts[0] && $opts[0] !~ /^-/;
     
@@ -35,12 +37,46 @@ sub import {
     
     set_target_dir($target_dir);
 
+    my $size = _get_buffer_size(\@opts);
+    set_buffer_size($size);
+    
+    # Set options
+    my $opts = 0;
+
+    # This option turns on actual writing to disc for the continous store,
+    # it's ment to be disabled when -die is in effect
+    $opts |= 0x1;
+    $opts ^= 0x1 if grep { $_ eq "-nostore" } @opts;
+    
+    # This option controls wether the buffer should be dumped into a file 
+    # when an exception is thrown
+    $opts |= 0x2 if grep { $_ eq "-die"} @opts;
+
+    set_options($opts);
+    
     # Maybe disable optimizer
     $^P = 4 if grep { $_ eq "-noopt" } @opts;
     
     init_recorder();
 }
 
+my %Size_multiplier = ( 
+    G => 1_073_741_824, M => 1_048_576, K => 1024,
+    g => 1_000_000_000, m => 1_000_000, k => 1000,
+);
+
+sub _get_buffer_size {
+    my $opts = shift;
+    
+    for my $opt (@$opts) {
+        if ($opt =~ /^-bs=(\d+(?:\.\d+)?)([GMK])?/i) {
+            return $2 ? $1 * $Size_multiplier{$2} : int $1;    
+        }
+    }
+    
+    return DEFAULT_BUFFER_SIZE;
+}
+
 1;
 __END__
 =head1 NAME
@@ -68,9 +104,18 @@ that can later be viewed using the rr-viewer tool.
 Simply use this module and it'll replace perl's standard runloop with its own. By 
 default a recording goes into a directory named rr-<date>-_<time>. If you want an 
 alternate name just pass it as the first argument to the use (eg -MRunops::Recorder=foo). 
+
 Sometimes perl will optimize away COPs and this may look confusing when viewing. If you 
 want to turn of the optimizer pass C<-noopt> when using this module.
 
+It's possible to adjust the buffer size which is how much it'll keep in memory before flushing 
+it to disk. This is done by passing C<-bs=SIZE> where SIZE is a number followed by an optional G/M/K/g/m/k 
+to denote the multiple. G, M and K are base-2 and g, m, k base-10. So 512K would be 524288 bytes. 
+If ommited a default of 64K is used. The minimum size is 128 bytes.
+
+It is possible to prevent continous store to disk with C<-nostore>. This is ment to be used 
+with C<-die> that dumps the buffer to disk when an exception occurs.
+
 =head1 VIEWING THE RECORDING
 
 Use the 'rr-viewer' tool. It just takes the path with the recording as an argument. 
